==> aws-java-sdk-opsworks-1.11.64-sources.jar: com/amazonaws/services/opsworks/model/transform/AttachElasticLoadBalancerRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.opsworks.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * AttachElasticLoadBalancerRequest Marshaller
 */
public class AttachElasticLoadBalancerRequestMarshaller implements Marshaller<Request<AttachElasticLoadBalancerRequest>, AttachElasticLoadBalancerRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public AttachElasticLoadBalancerRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<AttachElasticLoadBalancerRequest> marshall(AttachElasticLoadBalancerRequest attachElasticLoadBalancerRequest) {

        if (attachElasticLoadBalancerRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<AttachElasticLoadBalancerRequest> request = new DefaultRequest<AttachElasticLoadBalancerRequest>(attachElasticLoadBalancerRequest,
                "AWSOpsWorks");
        request.addHeader("X-Amz-Target", "OpsWorks_20130218.AttachElasticLoadBalancer");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (attachElasticLoadBalancerRequest.getElasticLoadBalancerName() != null) {
                jsonGenerator.writeFieldName("ElasticLoadBalancerName").writeValue(attachElasticLoadBalancerRequest.getElasticLoadBalancerName());
            }
            if (attachElasticLoadBalancerRequest.getLayerId() != null) {
                jsonGenerator.writeFieldName("LayerId").writeValue(attachElasticLoadBalancerRequest.getLayerId());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-opsworks-1.11.75-sources.jar: com/amazonaws/services/opsworks/model/transform/AttachElasticLoadBalancerRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.opsworks.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.opsworks.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * AttachElasticLoadBalancerRequest Marshaller
 */
public class AttachElasticLoadBalancerRequestMarshaller implements Marshaller<Request<AttachElasticLoadBalancerRequest>, AttachElasticLoadBalancerRequest> {

    private final SdkJsonMarshallerFactory protocolFactory;

    public AttachElasticLoadBalancerRequestMarshaller(SdkJsonMarshallerFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<AttachElasticLoadBalancerRequest> marshall(AttachElasticLoadBalancerRequest attachElasticLoadBalancerRequest) {

        if (attachElasticLoadBalancerRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<AttachElasticLoadBalancerRequest> request = new DefaultRequest<AttachElasticLoadBalancerRequest>(attachElasticLoadBalancerRequest,
                "AWSOpsWorks");
        request.addHeader("X-Amz-Target", "OpsWorks_20130218.AttachElasticLoadBalancer");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (attachElasticLoadBalancerRequest.getElasticLoadBalancerName() != null) {
                jsonGenerator.writeFieldName("ElasticLoadBalancerName").writeValue(attachElasticLoadBalancerRequest.getElasticLoadBalancerName());
            }
            if (attachElasticLoadBalancerRequest.getLayerId() != null) {
                jsonGenerator.writeFieldName("LayerId").writeValue(attachElasticLoadBalancerRequest.getLayerId());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
